using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace HierGridExpExcel
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // Bind the DataSet to the Grid
            this.ultraGrid1.DataSource = GetEmployDepartmentDataSet();
            this.ultraGrid1.DataBind();
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[1].Indentation = 0;
            e.Layout.Bands[2].Indentation = 0;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            ultraGridExcelExporter1.Export(ultraGrid1, "Grid1.xls");
            System.Diagnostics.Process.Start("Grid1.xls");
        }

        private void ultraGridExcelExporter1_RowExporting(object sender, Infragistics.Win.UltraWinGrid.ExcelExport.RowExportingEventArgs e)
        {
            if (e.GridRow.Band.Key == "DepartmentEmployee2")
            {
                e.CurrentColumnIndex = 0;
            }
        }

        private void ultraGridExcelExporter1_HeaderRowExporting(object sender, Infragistics.Win.UltraWinGrid.ExcelExport.HeaderRowExportingEventArgs e)
        {
            if (e.GridRow.Band.Key == "DepartmentEmployee2")
            {
                e.CurrentColumnIndex = 0;
            }
        }

        #region SampleData

        enum SampleTables
        {
            Departments,
            Employees1,
            Employees2
        }

        private DataTable GetSampleTable(SampleTables table)
        {
            DataTable retVal;
            switch (table)
            {
                case SampleTables.Departments:
                    retVal = this.GetDepartments();
                    break;
                case SampleTables.Employees1:
                    retVal = this.GetEmployees();
                    break;
                default:
                    retVal = this.GetEmployees();
                    break;
            }
            return retVal;
        }

        private DataSet GetEmployDepartmentDataSet()
        {
            DataSet ds = new DataSet("EmployeeRecords");

            // Get the tables to use in the DataSet
            DataTable Departments = this.GetDepartments();
            DataTable Employees1 = this.GetEmployees1(24);
            DataTable Employees2 = this.GetEmployees2(24);

            // Add the tables to the DataSet
            ds.Tables.Add(Departments);
            ds.Tables.Add(Employees1);
            ds.Tables.Add(Employees2);

            // Create the relationship between the Parent and Child Tables.
            ds.Relations.Add("DepartmentEmployee1", Departments.Columns["DepartmentID"], Employees1.Columns["DepartmentID"]);
            ds.Relations.Add("DepartmentEmployee2", Departments.Columns["DepartmentID"], Employees2.Columns["DepartmentID"]);
            return ds;
        }

        private DataTable GetDepartments()
        {
            DataTable dt = new DataTable("Departments");
            dt.Columns.Add("DepartmentID", typeof(int));
            dt.Columns.Add("DepartmentName", typeof(string));

            for (int i = 0; i < 8; i++)
            {
                dt.Rows.Add(new object[] { i, string.Format("Department {0}", i) });
            }

            dt.PrimaryKey = new DataColumn[] { dt.Columns["DepartmentID"] };

            return dt;
        }

        private DataTable GetEmployees()
        {
            return this.GetEmployees1(24);
        }

        private DataTable GetEmployees1(int count)
        {
            DataTable dtData = new DataTable("Employees1");

            dtData.Columns.Add("EmployeeID", typeof(int));
            dtData.Columns.Add("Name", typeof(string));
            dtData.Columns.Add("OnSite", typeof(bool));
            dtData.Columns.Add("DateOfHire", typeof(DateTime));
            dtData.Columns.Add("DepartmentID", typeof(int));
            dtData.Columns.Add("Site", typeof(string));
            dtData.Columns.Add("DepartmentName", typeof(string));


            for (int i = 0; i < count; i++)
            {
                dtData.Rows.Add(new object[] { i, string.Format("Name {0}", i), (i % 2 == 0), DateTime.Today.Date.AddDays(-1 * i), i % 8, "http://www.google.com", string.Format("Department {0}", i) });
            }

            dtData.PrimaryKey = new DataColumn[] { dtData.Columns["EmployeeID"] };

            return dtData;
        }

        private DataTable GetEmployees2(int count)
        {
            DataTable dtData = new DataTable("Employees2");

            dtData.Columns.Add("EmployeeID", typeof(int));
            dtData.Columns.Add("Name", typeof(string));
            dtData.Columns.Add("OnSite", typeof(bool));
            dtData.Columns.Add("DateOfHire", typeof(DateTime));
            dtData.Columns.Add("DepartmentID", typeof(int));
            dtData.Columns.Add("Site", typeof(string));
            dtData.Columns.Add("DepartmentName", typeof(string));


            for (int i = 0; i < count; i++)
            {
                dtData.Rows.Add(new object[] { i, string.Format("Name {0}", i), (i % 2 == 0), DateTime.Today.Date.AddDays(-1 * i), i % 8, "http://www.google.com", string.Format("Department {0}", i) });
            }

            dtData.PrimaryKey = new DataColumn[] { dtData.Columns["EmployeeID"] };

            return dtData;
        }

        #endregion SampleData
    }
}